@@ -13,7 +13,7 @@ class ConfigurationBuilder:
 
     def fetch(self):
         configuration = {}
-        for app_name, module_name in settings.SCAN_MODULES.iteritems():
+        for app_name, module_name in settings.SCAN_MODULES.items():
             try:
                 __import__(module_name)
                 urls = sys.modules[module_name]
@@ -29,3 +29,4 @@ class ConfigurationBuilder:
         return self.configuration
 
 DEFAULT_CONFIGURATION_BUILDER = ConfigurationBuilder()
+
